<?php
	/**
	* SemanticTextAnnotator
	* An Extension to Semantic Mediawiki which allows users to semantically annotate texts.
	* @author Oliver Lutzi
	*/


	//Alert the user that this is not a valid entry point to MediaWiki
	if( !defined( 'MEDIAWIKI' ) ) {
		die( 'Not an entry point.' );
	}
	
	
	//Take credit for your work.
	//$wgExtensionCredits['others'][] = array(
	$wgExtensionCredits[defined( 'SEMANTIC_EXTENSION_TYPE' ) ? 'semantic' : 'specialpage'][] = array(
		'path' => __FILE__,
		//The name of the extension, which will appear on Special:Version.
		'name' => 'Semantic Text Annotator',
		//The version of the extension, which will appear on Special:Version.
		'version' => '0.1',
		//The name of the author, which will appear on Special:Version
		'author' => 'Oliver Lutzi',
		//The URL to a wiki page/web page with information about the extension, which will appear on Special:Version
		'url' => 'http://www.mediawiki.org/',
		//The description, which will appear on Special:Version
		'descriptionmsg' => 'sta-description',
	);
	
	
	//Define path of the Extension
	$dir = dirname(__FILE__);
	//Define path of Message File
	$wgExtensionMessagesFiles['SemanticTextAnnotator'] = "$dir/SemanticTextAnnotator.i18n.php";
	
	// Load the class that contains the Subclass of the class "SpecialPage"
	$wgAutoloadClasses['SpecialSemanticTextAnnotator'] = "$dir/SpecialSemanticTextAnnotator.php";
	// Extend the $wgSpecialPages-Array by the Value SemanticTextAnnotator (Klasse wurde in Zeile davor geladen)
	$wgSpecialPages['SemanticTextAnnotator'] = 'SpecialSemanticTextAnnotator';
	
	// Your special page gets put under a heading in Special:SpecialPage
	// Extend the $wgSpeicalPageGroups-Array by the Value Olivers Extensions
	$wgSpecialPageGroups['SemanticTextAnnotator'] = 'olivers';
	
		
	//Create new Namespace for the Extension
	define("NS_TEXTANNOTATION", 382);
	$wgExtraNamespaces[NS_TEXTANNOTATION] = "TextAnnotation";
	//Define Namespace:TextAnnotation as Namespace with Semantic Links
	$smwgNamespacesWithSemanticLinks += array(NS_TEXTANNOTATION => true);
	
	
	//Resources for the ResourceLoader	
	$wgResourceModules['ext.SemanticTextAnnotator'] = array (
			//Scripts to always include
			'scripts'		=>	array('scripts/STA_articleNS.js',
									  'scripts/annotation_mode.js',
								      'scripts/STA_AJAXcall.js',
									  'scripts/helpFunctions.js',
									  'scripts/posLocator.js',
									  'scripts/highlightAnnotations.js',
									  'scripts/getListOfAnnotationSerialNumbers.js',
									  'scripts/functionsForVisualisation.js',
									  'scripts/insertSpanNodeForEveryNode.js',
									  'scripts/STA_getAnnotatedText.js',
								),		
			//Styles to always include
			'styles'		=>	array('styles/STA.css'),
			//Modules which must be loaded before this module
			'dependencies'	=>	array('ext.semanticforms.main', 'ext.semanticforms.popupformedit'),
			'localBasePath'	=>	dirname(__FILE__),
			'remoteExtPath'	=>	'SemanticTextAnnotator',
			//'messages'		=>	array('sta-buttonannotate'),	
	);
	
	//Integrate File "STA_AjaxFunctions.php"
	include_once('STA_AjaxFunctions.php');
	global $wgAjaxExportList;
	//Registry for functions callable via AJAX; This is a way for extensions (and some functions)
	//to make functions callable from JavaScript (extensions acting as Ajax callbacks must register here).
	$wgAjaxExportList[] = 'sta_writeAnnotationProperties';
	$wgAjaxExportList[] = 'getHTMLContent';
	$wgAjaxExportList[] = 'getEditContent';
	$wgAjaxExportList[] = 'parseText';
	$wgAjaxExportList[] = 'sta_deleteAnnotationPage';
	$wgAjaxExportList[] = 'sta_editWikiPage';
	$wgAjaxExportList[] = 'sta_getCategory';
	$wgAjaxExportList[] = 'sta_inCategory';
	
	


	//register MediaWiki hooks
	//see: 'http://www.mediawiki.org/wiki/Manual:Hooks#Available_hooks'
	//see: 'http://www.mediawiki.org/wiki/Manual:Hooks/OutputPageBeforeHTML'
	$wgHooks['OutputPageBeforeHTML'][] = 'sta_hookOutputPageBeforeHTML';
	
	//see: 'http://svn.wikimedia.org/doc/classOutputPage.html'
	//see: 'http://www.mediawiki.org/wiki/Manual:Hooks/OutputPageBeforeHTML'
	function sta_hookOutputPageBeforeHTML (&$out, &$text) {
		
		if($out->getTitle()->getNamespace() == 0) {		//0 is the Aricle's Namespace
			$out->addModules('ext.SemanticTextAnnotator');
		}
		return true;
	}
	
	
	
	
	//**********************
	$wgResourceModules['ext.SemanticTextAnnotator.NS_TEXTANNOTATION'] = array (
			//Scripts to always include
			'scripts'		=>	array(
					'scripts/STA_textannotationNS.js',
					'scripts/STA_AJAXcall.js',	
					'scripts/STA_getAnnotatedText.js'			
			),
			'localBasePath'	=>	dirname(__FILE__),
			'remoteExtPath'	=>	'SemanticTextAnnotator',
			//'messages'		=>	array('sta-buttonannotate'),
	);
	
	$wgHooks['OutputPageBeforeHTML'][] = 'sta_hookOutputPageBeforeHTML2';
	$wgHooks['smwInitProperties'][] = 'sta_initProperties';
	
	//see: 'http://svn.wikimedia.org/doc/classOutputPage.html'
	//see: 'http://www.mediawiki.org/wiki/Manual:Hooks/OutputPageBeforeHTML'
	function sta_hookOutputPageBeforeHTML2 (&$out, &$text) {
		if($out->getTitle()->getNamespace() == 382) {		
			$out->addModules('ext.SemanticTextAnnotator.NS_TEXTANNOTATION');
		}
		return true;
	}
	
		
	function sta_initProperties(){
		if ( class_exists( 'SMWDIProperty' ) ) {
			SMWDIProperty::registerProperty( "__STA_ARTICLE_NAME", '_str', "STAarticleName", true );
			SMWDIProperty::registerProperty( "__STA_ANNOTATION_TYPE", '_str', "STAannotationType", true );
			SMWDIProperty::registerProperty( "__STA_ANNOTATION_DATE", '_str', "STAannotationDate", true );
			SMWDIProperty::registerProperty( "__STA_CREATED_BY", '_str', "STAcreatedBy", true );
			SMWDIProperty::registerProperty( "__STA_COMMENT", '_str', "STAcomment", true );
			SMWDIProperty::registerProperty( "__STA_ANNOTATED_TEXT", '_str', "STAcomment", true );
		} else {
			SMWPropertyValue::registerProperty( "__STA_ARTICLE_NAME", '_str', "STAarticleName", true );
			SMWPropertyValue::registerProperty( "__STA_ANNOTATION_TYPE", '_str', "STAannotationType", true );
			SMWPropertyValue::registerProperty( "__STA_ANNOTATION_DATE", '_str', "STAannotationDate", true );
			SMWPropertyValue::registerProperty( "__STA_CREATED_BY", '_str', "STAcreatedBy", true );
			SMWPropertyValue::registerProperty( "__STA_COMMENT", '_str', "STAcomment", true );
			SMWPropertyValue::registerProperty( "__STA_ANNOTATED_TEXT", '_str', "STAannotatedText", true );
		}
		
		return true;
	}
	
	
	
	
?>